@@ -1,4 +1,4 @@
-from typing import Dict, List, Union  # isort:skip
+from typing import Dict, List, Union
 
 import deprecation
 
@@ -10,16 +10,22 @@ from catalyst.dl import MetricAggregationCallback
     deprecated_in="20.03",
     removed_in="20.04",
     current_version=__version__,
-    details="Use MetricAggregationCallback instead."
+    details="Use MetricAggregationCallback instead.",
 )
 class CriterionAggregatorCallback(MetricAggregationCallback):
+    """@TODO: Docs. Contribution is welcome."""
+
     def __init__(
         self,
         prefix: str,
         loss_keys: Union[str, List[str], Dict[str, float]] = None,
         loss_aggregate_fn: str = "sum",
-        multiplier: float = 1.0
+        multiplier: float = 1.0,
     ):
+        """
+        Args:
+            @TODO: Docs. Contribution is welcome.
+        """
         super().__init__(
             prefix=prefix,
             metrics=loss_keys,
