@@ -1,6 +1,9 @@
 # flake8: noqa
 
 from .functional import get_convolution_net, get_linear_net
+from .hydra import Hydra
 from .sequential import (
-    _process_additional_params, ResidualWrapper, SequentialNet
+    _process_additional_params,
+    ResidualWrapper,
+    SequentialNet,
 )
