@@ -13,7 +13,13 @@ from catalyst.dl import Callback, CallbackOrder, State, utils
 
 # @TODO: refactor
 class InferCallback(Callback):
+    """@TODO: Docs. Contribution is welcome."""
+
     def __init__(self, out_dir=None, out_prefix=None):
+        """
+        Args:
+            @TODO: Docs. Contribution is welcome
+        """
         super().__init__(CallbackOrder.Internal)
         self.out_dir = out_dir
         self.out_prefix = out_prefix
@@ -21,6 +27,11 @@ class InferCallback(Callback):
         self._keys_from_state = ["out_dir", "out_prefix"]
 
     def on_stage_start(self, state: State):
+        """Stage start hook.
+
+        Args:
+            state (State): current state
+        """
         for key in self._keys_from_state:
             value = getattr(state, key, None)
             if value is not None:
@@ -32,15 +43,30 @@ class InferCallback(Callback):
             os.makedirs(os.path.dirname(self.out_prefix), exist_ok=True)
 
     def on_loader_start(self, state: State):
+        """Loader start hook.
+
+        Args:
+            state (State): current state
+        """
         self.predictions = defaultdict(lambda: [])
 
     def on_batch_end(self, state: State):
+        """Batch end hook.
+
+        Args:
+            state (State): current state
+        """
         dct = state.batch_out
         dct = {key: value.detach().cpu().numpy() for key, value in dct.items()}
         for key, value in dct.items():
             self.predictions[key].append(value)
 
     def on_loader_end(self, state: State):
+        """Loader end hook.
+
+        Args:
+            state (State): current state
+        """
         self.predictions = {
             key: np.concatenate(value, axis=0)
             for key, value in self.predictions.items()
@@ -52,6 +78,8 @@ class InferCallback(Callback):
 
 
 class InferMaskCallback(Callback):
+    """@TODO: Docs. Contribution is welcome."""
+
     def __init__(
         self,
         out_dir=None,
@@ -63,8 +91,12 @@ class InferMaskCallback(Callback):
         std=None,
         threshold: float = 0.5,
         mask_strength: float = 0.5,
-        mask_type: str = "soft"
+        mask_type: str = "soft",
     ):
+        """
+        Args:
+            @TODO: Docs. Contribution is welcome
+        """
         super().__init__(CallbackOrder.Internal)
         self.out_dir = out_dir
         self.out_prefix = out_prefix
@@ -82,23 +114,38 @@ class InferMaskCallback(Callback):
         self._keys_from_state = ["out_dir", "out_prefix"]
 
     def on_stage_start(self, state: State):
+        """Stage start hook.
+
+        Args:
+            state (State): current state
+        """
         for key in self._keys_from_state:
             value = getattr(state, key, None)
             if value is not None:
                 setattr(self, key, value)
         # assert self.out_prefix is not None
-        self.out_prefix = self.out_prefix \
-            if self.out_prefix is not None \
-            else ""
+        self.out_prefix = (
+            self.out_prefix if self.out_prefix is not None else ""
+        )
         if self.out_dir is not None:
             self.out_prefix = str(self.out_dir) + "/" + str(self.out_prefix)
         os.makedirs(os.path.dirname(self.out_prefix), exist_ok=True)
 
     def on_loader_start(self, state: State):
+        """Loader start hook.
+
+        Args:
+            state (State): current state
+        """
         lm = state.loader_name
         os.makedirs(f"{self.out_prefix}/{lm}/", exist_ok=True)
 
     def on_batch_end(self, state: State):
+        """Batch end hook.
+
+        Args:
+            state (State): current state
+        """
         lm = state.loader_name
         names = state.batch_in.get(self.name_key, [])
 
@@ -106,9 +153,11 @@ class InferMaskCallback(Callback):
         images = utils.tensor_to_ndimage(features)
 
         logits = state.batch_out[self.output_key]
-        logits = torch.unsqueeze_(logits, dim=1) \
-            if len(logits.shape) < 4 \
+        logits = (
+            torch.unsqueeze_(logits, dim=1)
+            if len(logits.shape) < 4
             else logits
+        )
 
         if self.mask_type == "soft":
             probabilities = torch.sigmoid(logits)
@@ -132,8 +181,9 @@ class InferMaskCallback(Callback):
 
             mask = label2rgb(mask, bg_label=0)
 
-            image = image * (1 - self.mask_strength) \
-                + mask * self.mask_strength
+            image = (
+                image * (1 - self.mask_strength) + mask * self.mask_strength
+            )
             image = (image * 255).clip(0, 255).round().astype(np.uint8)
 
             filename = f"{self.out_prefix}/{lm}/{suffix}.jpg"
