@@ -1,34 +1,46 @@
-from typing import Any, Callable, Dict, List, Mapping, Union  # isort:skip
+from typing import Any, Callable, Dict, List, Mapping, Union
 from collections import OrderedDict
 from copy import deepcopy
 
 import torch
 from torch import nn
-from torch.utils.data import (  # noqa F401
-    DataLoader, Dataset, DistributedSampler
-)
+from torch.utils.data import DataLoader  # noqa F401
 
-from catalyst.data import (
-    Augmentor, AugmentorCompose, DistributedSamplerWrapper
-)
+from catalyst.core import StageBasedExperiment
+from catalyst.data import Augmentor, AugmentorCompose
 from catalyst.dl import (
-    Callback, CheckpointCallback, CheckRunCallback, ConsoleLogger,
-    CriterionCallback, ExceptionCallback, Experiment, MetricManagerCallback,
-    OptimizerCallback, PhaseWrapperCallback, SchedulerCallback,
-    TensorboardLogger, TimerCallback, utils, ValidationManagerCallback,
-    VerboseLogger
+    Callback,
+    CheckpointCallback,
+    CheckRunCallback,
+    ConsoleLogger,
+    CriterionCallback,
+    ExceptionCallback,
+    MetricManagerCallback,
+    OptimizerCallback,
+    PhaseWrapperCallback,
+    SchedulerCallback,
+    TensorboardLogger,
+    TimerCallback,
+    utils,
+    ValidationManagerCallback,
+    VerboseLogger,
 )
 from catalyst.dl.registry import (
-    CALLBACKS, CRITERIONS, MODELS, OPTIMIZERS, SAMPLERS, SCHEDULERS,
-    TRANSFORMS
+    CALLBACKS,
+    CRITERIONS,
+    MODELS,
+    OPTIMIZERS,
+    SCHEDULERS,
+    TRANSFORMS,
 )
 from catalyst.utils.tools.typing import Criterion, Model, Optimizer, Scheduler
 
 
-class ConfigExperiment(Experiment):
+class ConfigExperiment(StageBasedExperiment):
     """
-    Experiment created from a configuration file
+    Experiment created from a configuration file.
     """
+
     STAGE_KEYWORDS = [
         "criterion_params",
         "optimizer_params",
@@ -44,17 +56,27 @@ class ConfigExperiment(Experiment):
         Args:
             config (dict): dictionary of parameters
         """
-        self._config = deepcopy(config)
-        self._initial_seed = self._config.get("args", {}).get("seed", 42)
-        self._verbose = self._config.get("args", {}).get("verbose", False)
-        self._check_run = self._config.get("args", {}).get("check", False)
+        self._config: Dict = deepcopy(config)
+        self._initial_seed: int = self._config.get("args", {}).get("seed", 42)
+        self._verbose: bool = self._config.get("args", {}).get(
+            "verbose", False
+        )
+        self._check_run: bool = self._config.get("args", {}).get(
+            "check", False
+        )
+        self._check_time: bool = self._config.get("args", {}).get(
+            "timeit", False
+        )
         self.__prepare_logdir()
 
         self._config["stages"]["state_params"] = utils.merge_dicts(
             deepcopy(self._config["stages"].get("state_params", {})),
-            deepcopy(self._config.get("args", {})), {"logdir": self._logdir}
+            deepcopy(self._config.get("args", {})),
+            {"logdir": self._logdir},
+        )
+        self.stages_config: Dict = self._get_stages_config(
+            self._config["stages"]
         )
-        self.stages_config = self._get_stages_config(self._config["stages"])
 
     def __prepare_logdir(self):
         EXCLUDE_TAG = "none"
@@ -70,14 +92,16 @@ class ConfigExperiment(Experiment):
         else:
             self._logdir = None
 
-    def _get_stages_config(self, stages_config):
+    def _get_stages_config(self, stages_config: Dict):
         stages_defaults = {}
         stages_config_out = OrderedDict()
         for key in self.STAGE_KEYWORDS:
             stages_defaults[key] = deepcopy(stages_config.get(key, {}))
         for stage in stages_config:
-            if stage in self.STAGE_KEYWORDS \
-                    or stages_config.get(stage) is None:
+            if (
+                stage in self.STAGE_KEYWORDS
+                or stages_config.get(stage) is None
+            ):
                 continue
             stages_config_out[stage] = {}
             for key in self.STAGE_KEYWORDS:
@@ -92,24 +116,21 @@ class ConfigExperiment(Experiment):
         timestamp = utils.get_utcnow_time()
         config_hash = utils.get_short_hash(config)
         logdir = f"{timestamp}.{config_hash}"
-        distributed_rank = utils.get_rank()
-        if distributed_rank > -1:
-            logdir = f"{logdir}.rank{distributed_rank:02d}"
         return logdir
 
     @property
     def initial_seed(self) -> int:
-        """Experiment's initial seed value"""
+        """Experiment's initial seed value."""
         return self._initial_seed
 
     @property
     def logdir(self):
-        """Path to the directory where the experiment logs"""
+        """Path to the directory where the experiment logs."""
         return self._logdir
 
     @property
     def stages(self) -> List[str]:
-        """Experiment's stage names"""
+        """Experiment's stage names."""
         stages_keys = list(self.stages_config.keys())
 
         # @TODO: return the feature
@@ -132,23 +153,22 @@ class ConfigExperiment(Experiment):
 
     @property
     def distributed_params(self) -> Dict:
-        """Dict with the parameters for distributed and FP16 methond"""
+        """Dict with the parameters for distributed and FP16 methond."""
         return self._config.get("distributed_params", {})
 
     @property
     def monitoring_params(self) -> Dict:
-        """Dict with the parameters for monitoring services"""
+        """Dict with the parameters for monitoring services."""
         return self._config.get("monitoring_params", {})
 
     def get_state_params(self, stage: str) -> Mapping[str, Any]:
-        """Returns the state parameters for a given stage"""
+        """Returns the state parameters for a given stage."""
         return self.stages_config[stage].get("state_params", {})
 
     def _preprocess_model_for_stage(self, stage: str, model: Model):
         stage_index = self.stages.index(stage)
         if stage_index > 0:
-            checkpoint_path = \
-                f"{self.logdir}/checkpoints/best.pth"
+            checkpoint_path = f"{self.logdir}/checkpoints/best.pth"
             checkpoint = utils.load_checkpoint(checkpoint_path)
             utils.unpack_checkpoint(checkpoint, model=model)
         return model
@@ -170,7 +190,7 @@ class ConfigExperiment(Experiment):
         return model
 
     def get_model(self, stage: str):
-        """Returns the model for a given stage"""
+        """Returns the model for a given stage."""
         model_params = self._config["model_params"]
         model = self._get_model(**model_params)
 
@@ -193,9 +213,10 @@ class ConfigExperiment(Experiment):
         return criterion
 
     def get_criterion(self, stage: str) -> Criterion:
-        """Returns the criterion for a given stage"""
-        criterion_params = \
-            self.stages_config[stage].get("criterion_params", {})
+        """Returns the criterion for a given stage."""
+        criterion_params = self.stages_config[stage].get(
+            "criterion_params", {}
+        )
         criterion = self._get_criterion(**criterion_params)
         return criterion
 
@@ -204,10 +225,8 @@ class ConfigExperiment(Experiment):
     ) -> Optimizer:
         # @TODO 1: refactoring; this method is too long
         # @TODO 2: load state dicts for schedulers & criterion
-        layerwise_params = \
-            params.pop("layerwise_params", OrderedDict())
-        no_bias_weight_decay = \
-            params.pop("no_bias_weight_decay", True)
+        layerwise_params = params.pop("layerwise_params", OrderedDict())
+        no_bias_weight_decay = params.pop("no_bias_weight_decay", True)
 
         # linear scaling rule from https://arxiv.org/pdf/1706.02677.pdf
         lr_scaling_params = params.pop("lr_linear_scaling", None)
@@ -231,29 +250,35 @@ class ConfigExperiment(Experiment):
         # getting model parameters
         model_key = params.pop("_model", None)
         if model_key is None:
-            assert isinstance(model, nn.Module), \
-                "model is keyvalue, but optimizer has no specified model"
+            assert isinstance(
+                model, nn.Module
+            ), "model is key-value, but optimizer has no specified model"
             model_params = utils.process_model_params(
                 model, layerwise_params, no_bias_weight_decay, lr_scaling
             )
         elif isinstance(model_key, str):
             model_params = utils.process_model_params(
-                model[model_key], layerwise_params, no_bias_weight_decay,
-                lr_scaling
+                model[model_key],
+                layerwise_params,
+                no_bias_weight_decay,
+                lr_scaling,
             )
         elif isinstance(model_key, (list, tuple)):
             model_params = []
             for model_key_ in model_key:
                 model_params_ = utils.process_model_params(
-                    model[model_key_], layerwise_params, no_bias_weight_decay,
-                    lr_scaling
+                    model[model_key_],
+                    layerwise_params,
+                    no_bias_weight_decay,
+                    lr_scaling,
                 )
                 model_params.extend(model_params_)
         else:
             raise ValueError("unknown type of model_params")
 
-        load_from_previous_stage = \
-            params.pop("load_from_previous_stage", False)
+        load_from_previous_stage = params.pop(
+            "load_from_previous_stage", False
+        )
         optimizer_key = params.pop("optimizer_key", None)
         optimizer = OPTIMIZERS.get_from_params(**params, params=model_params)
 
@@ -284,15 +309,15 @@ class ConfigExperiment(Experiment):
     def get_optimizer(
         self, stage: str, model: Union[Model, Dict[str, Model]]
     ) -> Union[Optimizer, Dict[str, Optimizer]]:
-        """
-        Returns the optimizer for a given stage
+        """Returns the optimizer for a given stage.
 
         Args:
             stage (str): stage name
             model (Union[Model, Dict[str, Model]]): model or a dict of models
         """
-        optimizer_params = \
-            self.stages_config[stage].get("optimizer_params", {})
+        optimizer_params = self.stages_config[stage].get(
+            "optimizer_params", {}
+        )
         key_value_flag = optimizer_params.pop("_key_value", False)
 
         if key_value_flag:
@@ -326,9 +351,10 @@ class ConfigExperiment(Experiment):
         return scheduler
 
     def get_scheduler(self, stage: str, optimizer: Optimizer) -> Scheduler:
-        """Returns the scheduler for a given stage"""
-        scheduler_params = \
-            self.stages_config[stage].get("scheduler_params", {})
+        """Returns the scheduler for a given stage."""
+        scheduler_params = self.stages_config[stage].get(
+            "scheduler_params", {}
+        )
         scheduler = self._get_scheduler(
             optimizer=optimizer, **scheduler_params
         )
@@ -370,8 +396,7 @@ class ConfigExperiment(Experiment):
     def get_transforms(
         self, stage: str = None, dataset: str = None
     ) -> Callable:
-        """
-        Returns transform for a given stage & mode
+        """Returns transform for a given stage and mode.
 
         Args:
             stage (str): stage name
@@ -391,6 +416,7 @@ class ConfigExperiment(Experiment):
 
             def transform(dict_):
                 return dict_
+
         elif not isinstance(transform, AugmentorCompose):
             transform_ = transform
 
@@ -400,110 +426,16 @@ class ConfigExperiment(Experiment):
         return transform
 
     def get_loaders(
-        self,
-        stage: str,
-        epoch: int = None,
+        self, stage: str, epoch: int = None,
     ) -> "OrderedDict[str, DataLoader]":
-        """Returns the loaders for a given stage"""
+        """Returns the loaders for a given stage."""
         data_params = dict(self.stages_config[stage]["data_params"])
-
-        default_batch_size = data_params.pop("batch_size", 1)
-        default_num_workers = data_params.pop("num_workers")
-        drop_last = data_params.pop("drop_last", False)
-        per_gpu_scaling = data_params.pop("per_gpu_scaling", False)
-        distributed_rank = utils.get_rank()
-        distributed = distributed_rank > -1
-
-        datasets = self.get_datasets(stage=stage, **data_params)
-
-        overridden_loaders_params = data_params.pop("loaders_params", {})
-        assert isinstance(overridden_loaders_params, dict), (
-            f"`overridden_loaders_params` should be a Dict. "
-            f"Got: {overridden_loaders_params}"
+        loaders = utils.get_loaders_from_params(
+            get_datasets_fn=self.get_datasets,
+            initial_seed=self.initial_seed,
+            stage=stage,
+            **data_params,
         )
-
-        samplers_params = data_params.pop("samplers_params", {})
-        assert isinstance(samplers_params, dict), \
-            f"`samplers_params` should be a Dict. Got: {samplers_params}"
-
-        loaders = OrderedDict()
-        for name, ds_ in datasets.items():
-            assert isinstance(ds_, (Dataset, dict)), \
-                f"{ds_} should be Dataset or Dict"
-
-            overridden_loader_params = overridden_loaders_params.pop(name, {})
-            assert isinstance(overridden_loader_params, dict), \
-                f"{overridden_loader_params} should be Dict"
-
-            sampler_params = samplers_params.pop(name, None)
-            if sampler_params is None:
-                if isinstance(ds_, dict) and "sampler" in ds_:
-                    sampler = ds_.pop("sampler", None)
-                else:
-                    sampler = None
-            else:
-                sampler = SAMPLERS.get_from_params(**sampler_params)
-                if isinstance(ds_, dict) and "sampler" in ds_:
-                    ds_.pop("sampler", None)
-
-            batch_size = overridden_loader_params.\
-                pop("batch_size", default_batch_size)
-            num_workers = overridden_loader_params.\
-                pop("num_workers", default_num_workers)
-
-            if per_gpu_scaling and not distributed:
-                num_gpus = max(1, torch.cuda.device_count())
-                batch_size *= num_gpus
-                num_workers *= num_gpus
-
-            loader_params = {
-                "batch_size": batch_size,
-                "num_workers": num_workers,
-                "pin_memory": torch.cuda.is_available(),
-                "drop_last": drop_last,
-                **overridden_loader_params
-            }
-
-            if isinstance(ds_, Dataset):
-                loader_params["dataset"] = ds_
-            elif isinstance(ds_, dict):
-                assert "dataset" in ds_, \
-                    "You need to specify dataset for dataloader"
-                loader_params = utils.merge_dicts(ds_, loader_params)
-            else:
-                raise NotImplementedError
-
-            if distributed:
-                if sampler is not None:
-                    if not isinstance(sampler, DistributedSampler):
-                        sampler = DistributedSamplerWrapper(sampler=sampler)
-                else:
-                    sampler = DistributedSampler(
-                        dataset=loader_params["dataset"]
-                    )
-
-            loader_params["shuffle"] = (
-                name.startswith("train") and sampler is None
-            )
-
-            loader_params["sampler"] = sampler
-
-            if "batch_sampler" in loader_params:
-                if distributed:
-                    raise ValueError(
-                        "batch_sampler option is mutually "
-                        "exclusive with distributed"
-                    )
-
-                for k in ("batch_size", "shuffle", "sampler", "drop_last"):
-                    loader_params.pop(k, None)
-
-            if "worker_init_fn" not in loader_params:
-                loader_params["worker_init_fn"] = \
-                    lambda x: utils.set_global_seed(self.initial_seed + x)
-
-            loaders[name] = DataLoader(**loader_params)
-
         return loaders
 
     @staticmethod
@@ -516,9 +448,9 @@ class ConfigExperiment(Experiment):
         return callback
 
     def get_callbacks(self, stage: str) -> "OrderedDict[Callback]":
-        """Returns the callbacks for a given stage"""
-        callbacks_params = (
-            self.stages_config[stage].get("callbacks_params", {})
+        """Returns the callbacks for a given stage."""
+        callbacks_params = self.stages_config[stage].get(
+            "callbacks_params", {}
         )
 
         callbacks = OrderedDict()
@@ -529,10 +461,22 @@ class ConfigExperiment(Experiment):
         default_callbacks = []
         if self._verbose:
             default_callbacks.append(("_verbose", VerboseLogger))
+        if self._check_time:
+            default_callbacks.append(("_timer", TimerCallback))
         if self._check_run:
             default_callbacks.append(("_check", CheckRunCallback))
 
         if not stage.startswith("infer"):
+            default_callbacks.append(("_metrics", MetricManagerCallback))
+            default_callbacks.append(
+                ("_validation", ValidationManagerCallback)
+            )
+            default_callbacks.append(("_console", ConsoleLogger))
+
+            if self.logdir is not None:
+                default_callbacks.append(("_saver", CheckpointCallback))
+                default_callbacks.append(("_tensorboard", TensorboardLogger))
+
             if self.stages_config[stage].get("criterion_params", {}):
                 default_callbacks.append(("_criterion", CriterionCallback))
             if self.stages_config[stage].get("optimier_params", {}):
@@ -540,14 +484,6 @@ class ConfigExperiment(Experiment):
             if self.stages_config[stage].get("scheduler_params", {}):
                 default_callbacks.append(("_scheduler", SchedulerCallback))
 
-            default_callbacks.append(("_timer", TimerCallback))
-            default_callbacks.append(("_metrics", MetricManagerCallback))
-            default_callbacks.append(
-                ("_validation", ValidationManagerCallback)
-            )
-            default_callbacks.append(("_saver", CheckpointCallback))
-            default_callbacks.append(("_console", ConsoleLogger))
-            default_callbacks.append(("_tensorboard", TensorboardLogger))
         default_callbacks.append(("_exception", ExceptionCallback))
 
         for callback_name, callback_fn in default_callbacks:
