@@ -1,7 +1,19 @@
 from catalyst.contrib.registry import (
-    Criterion, CRITERIONS, GRAD_CLIPPERS, Model, MODELS, Module, MODULES,
-    Optimizer, OPTIMIZERS, Sampler, SAMPLERS, Scheduler, SCHEDULERS, Transform,
-    TRANSFORMS
+    Criterion,
+    CRITERIONS,
+    GRAD_CLIPPERS,
+    Model,
+    MODELS,
+    Module,
+    MODULES,
+    Optimizer,
+    OPTIMIZERS,
+    Sampler,
+    SAMPLERS,
+    Scheduler,
+    SCHEDULERS,
+    Transform,
+    TRANSFORMS,
 )
 from catalyst.core.registry import Callback, CALLBACKS
 from catalyst.utils.tools.registry import Registry
@@ -9,6 +21,7 @@ from catalyst.utils.tools.registry import Registry
 
 def _callbacks_loader(r: Registry):
     from catalyst.dl import callbacks as m
+
     r.add_from_module(m)
 
 
