@@ -6,11 +6,11 @@ import os
 from pathlib import Path
 
 from catalyst.dl import utils
-from catalyst.utils import distributed_run, get_rank
+from catalyst.utils import distributed_cmd_run, get_rank
 
 
 def build_args(parser: ArgumentParser):
-    """Constructs the command-line arguments for ``catalyst-dl run``"""
+    """Constructs the command-line arguments for ``catalyst-dl run``."""
     parser.add_argument(
         "--config",
         "--configs",
@@ -19,7 +19,7 @@ def build_args(parser: ArgumentParser):
         help="path to config/configs",
         metavar="CONFIG_PATH",
         dest="configs",
-        required=True
+        required=True,
     )
     parser.add_argument("--expdir", type=str, default=None)
     parser.add_argument("--logdir", type=str, default=None)
@@ -29,7 +29,7 @@ def build_args(parser: ArgumentParser):
         "--num-workers",
         default=None,
         type=int,
-        help="number of data loading workers"
+        help="number of data loading workers",
     )
     parser.add_argument(
         "-b", "--batch-size", default=None, type=int, help="mini-batch size"
@@ -42,7 +42,7 @@ def build_args(parser: ArgumentParser):
         default=None,
         type=str,
         metavar="PATH",
-        help="path to latest checkpoint"
+        help="path to latest checkpoint",
     )
     parser.add_argument(
         "--autoresume",
@@ -53,29 +53,30 @@ def build_args(parser: ArgumentParser):
         ),
         required=False,
         choices=["best", "last"],
-        default=None
+        default=None,
     )
     parser.add_argument("--seed", type=int, default=42)
     utils.boolean_flag(
         parser,
         "apex",
         default=os.getenv("USE_APEX", "1") == "1",
-        help="Enable/disable using of Apex extension"
+        help="Enable/disable using of Apex extension",
     )
     utils.boolean_flag(
         parser,
         "distributed",
         shorthand="ddp",
         default=os.getenv("USE_DDP", "0") == "1",
-        help="Run inn distributed mode"
+        help="Run in distributed mode",
     )
     utils.boolean_flag(parser, "verbose", default=None)
+    utils.boolean_flag(parser, "timeit", default=None)
     utils.boolean_flag(parser, "check", default=None)
     utils.boolean_flag(
         parser,
         "deterministic",
         default=None,
-        help="Deterministic mode if running in CuDNN backend"
+        help="Deterministic mode if running in CuDNN backend",
     )
     utils.boolean_flag(
         parser, "benchmark", default=None, help="Use CuDNN benchmark"
@@ -85,7 +86,7 @@ def build_args(parser: ArgumentParser):
 
 
 def parse_args():
-    """Parses the command line arguments and returns arguments and config"""
+    """Parses the command line arguments and returns arguments and config."""
     parser = argparse.ArgumentParser()
     build_args(parser)
     args, unknown_args = parser.parse_known_args()
@@ -93,6 +94,7 @@ def parse_args():
 
 
 def main_worker(args, unknown_args):
+    """@TODO: Docs. Contribution is welcome."""
     args, config = utils.parse_args_uargs(args, unknown_args)
     utils.set_global_seed(args.seed)
     utils.prepare_cudnn(args.deterministic, args.benchmark)
@@ -113,8 +115,8 @@ def main_worker(args, unknown_args):
 
 
 def main(args, unknown_args):
-    """Run the ``catalyst-dl run`` script"""
-    distributed_run(args.distributed, main_worker, args, unknown_args)
+    """Run the ``catalyst-dl run`` script."""
+    distributed_cmd_run(main_worker, args.distributed, args, unknown_args)
 
 
 if __name__ == "__main__":
