@@ -1,20 +1,28 @@
+"""
+Simple timer.
+"""
 from time import time
 
 
-class TimeManager:
+class TimeManager(object):
+    """@TODO: Docs. Contribution is welcome."""
+
     def __init__(self):
+        """@TODO: Docs. Contribution is welcome."""
         self._starts = {}
         self.elapsed = {}
 
     def start(self, name: str) -> None:
-        """Starts timer ``name``
+        """Starts timer ``name``.
+
         Args:
             name (str): name of a timer
         """
         self._starts[name] = time()
 
     def stop(self, name: str) -> None:
-        """Stops timer ``name``
+        """Stops timer ``name``.
+
         Args:
             name (str): name of a timer
         """
@@ -24,7 +32,7 @@ class TimeManager:
         del self._starts[name]
 
     def reset(self) -> None:
-        """Reset all previous timers"""
+        """Reset all previous timers."""
         self.elapsed = {}
         self._starts = {}
 
